;; Generated package description from xref.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "xref" "1.7.0.0.20260403.13314" "Cross-referencing commands" '((emacs "26.1")) :commit "86efaec00e01af1e9171c7fa9eb7904af3be0eb3" :url "https://elpa.gnu.org/packages/xref.html")
